/*
 * Copyright (C) 2013 Pablo Taboada
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package uoc.edu.ptaboada.tthome;

import uoc.edu.ptaboada.tthome.R;

import android.app.ActionBar;
import android.app.Activity;
import android.os.Bundle;
import android.widget.TextView;

/**
 * Representa un Centro de trabajo (casa, oficina, etc.)
 * 
 * @author Pablo Taboada
 * 
 */
public class Centro extends Activity {
	private int id;
	private String nombre;
	private String direccion;
	private String poblacion;
	private String provincia;
	private String cp;

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.detalle);
		
		Bundle extras = getIntent().getExtras();
		String nome = extras.getString("nome");
				
		ActionBar ab = getActionBar();
		ab.show();
		ab.setIcon(R.drawable.img_centros);
		ab.setTitle(nome);

		getDatosCentro(nome);

		TextView tv = (TextView) findViewById(R.id.detalle);
		tv.setText(
				 getString(R.string.nombre)+":    "+nombre+"\n"
				+getString(R.string.direccion)+": "+direccion+"\n"
				+getString(R.string.poblacion)+": "+poblacion+"\n"
				+getString(R.string.provincia)+": "+provincia+"\n"
				+getString(R.string.cp)+":        "+cp+"\n");
	}
	
	/**
	 * Constructor vacío para permitir la creación de una Activity vacía
	 */
	public Centro(){
		
	}
	
	/**
	 * Facilita la creación de un Centro proporcionando todos los datos del mismo.
	 * 
	 * @param id	identificador único del Centro de trabajo
	 * @param nom	nombre
	 * @param dir	dirección
	 * @param pob	población
	 * @param pro	provincia
	 * @param cp	código postal
	 */
	public Centro(int id, String nom, String dir, String pob, String pro, String cp){
		this.id = id;
		this.nombre = nom;
		this.direccion = dir;
		this.poblacion = pob;
		this.provincia = pro;
		this.cp = cp;
	}
	
	/**
	 * Devuelve únicamente el nombre del Centro (para poblar las listas)
	 * 
	 * @return	nombre del Centro
	 */
	@Override
	public String toString() {
		return nombre;
	}
	
	/**
	 * Asigna a este Centro los datos del Centro cuyo nombre se pasa por parámetro
	 * 
	 * @param nombre	nombre del Centro
	 */
	private void getDatosCentro(String nombre){
		TTApplication tt = (TTApplication)getApplication();
		for(int i=0; i<tt.centros.size(); i++){
			if(tt.centros.get(i).nombre.equals(nombre)){
				this.id = tt.centros.get(i).id;
				this.nombre = tt.centros.get(i).nombre;
				this.direccion = tt.centros.get(i).direccion;
				this.poblacion = tt.centros.get(i).poblacion;
				this.provincia = tt.centros.get(i).provincia;
				this.cp = tt.centros.get(i).cp;
				return;
			}
		}
		// TODO: realizar la búsqueda de datos del Centro en base a su ID en lugar de su nombre.
	}
}