/*
 * Copyright (C) 2013 Pablo Taboada
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package uoc.edu.ptaboada.tthome;

import uoc.edu.ptaboada.tthome.R;

import android.app.ActionBar;
import android.app.Activity;
import android.os.Bundle;
import android.widget.TextView;

/**
 * Representa un Empleado que realizará su actividad en un Centro.
 * 
 * @author Pablo Taboada
 *
 */
public class Empleado extends Activity {
	public int id;
	public String nombre;
	public String telefono;
	public String codigo;
	
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.detalle);
		
		Bundle extras = getIntent().getExtras();
		String nome = extras.getString("nome");
		
		ActionBar ab = getActionBar();
		ab.show();
		ab.setIcon(R.drawable.img_empleados);
		ab.setTitle(nome);

		getDatosEmpleado(nome);

		TextView tv = (TextView) findViewById(R.id.detalle);
		tv.setText(
				 getString(R.string.nombre)+":   "+nombre+"\n"
				+getString(R.string.telefono)+": "+telefono+"\n"
				+getString(R.string.codigo)+":   "+codigo+"\n");
	}
	
	/**
	 * Constructor vacío necesario para poder instanciar Activity
	 */
	public Empleado(){
		
	}
	
	/**
	 * Facilita la creación de un Empleado proporcionando todos sus datos.
	 * 
	 * @param id	identificador único del Empleado
	 * @param nom	nombre
	 * @param tel	teléfono al que debe llamar para realizar los fichajes
	 * @param cod	código que debe marcar el empleado para fichar
	 */
	public Empleado(int id, String nom, String tel, String cod){
		this.id = id;
		this.nombre = nom;
		this.telefono = tel;
		this.codigo = cod;
	}
	
	/**
	 * Devuelve únicamente el nombre del Empleado (para poblar las listas)
	 * 
	 * @return nombre del Empleado
	 */
	@Override
	public String toString() {
		return nombre;
	}
	
	/**
	 * Asigna a este Empleado los datos del Empleado cuyo nombre se pasa por parámetro
	 * 
	 * @param nombre	nombre del Empleado
	 */
	private void getDatosEmpleado(String nombre){
		TTApplication tt = (TTApplication)getApplication();
		for(int i=0; i<tt.empleados.size(); i++){
			if(tt.empleados.get(i).nombre.equals(nombre)){
				this.id = tt.empleados.get(i).id;
				this.nombre = tt.empleados.get(i).nombre;
				this.telefono = tt.empleados.get(i).telefono;
				this.codigo = tt.empleados.get(i).codigo;
				return;
			}
		}
		// TODO: realizar la búsqueda de datos del Empleado en base a su ID en lugar de su nombre.
	}
}

