/*
 * Copyright (C) 2013 Pablo Taboada
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package uoc.edu.ptaboada.tthome;

import java.util.ArrayList;

import android.app.Application;

/**
 * Parametrización de la aplicación para poder mantener variables globales comunes a todas las Activity.
 * Permite que se almacenen en la aplicación los datos recuperados del servidor, de modo que se minimizan
 * las consultas al servidor para obtener dichos datos.
 * 
 * Los datos NO son persistentes, elminándose cuando la aplicación es destruida. Esto garantiza que el usuario
 * no trabajará con datos obsoletos.
 * 
 * @author Pablo Taboada
 */
public class TTApplication extends Application {
	// Lista con todos los datos de empleados
    public ArrayList<Empleado> empleados = new ArrayList<Empleado>();
    // Lista con todos los datos de centros
    public ArrayList<Centro> centros = new ArrayList<Centro>();
    // Lista con todos los datos de turnos
    public ArrayList<Turno> turnos = new ArrayList<Turno>();
    // Token utilizado para la autenticación en el servidor con caducidad limitada.
    public String token = "";
    
    /**
     * Devuelve una lista (ArrayList) con los nombres de los empleados para poder cargar un ListView.
     * 
     * @return lista con los nombres de los empleados
     */
    public ArrayList<String> listaEmpleados(){
    	ArrayList<String> l = new ArrayList<String>();
    	for(int i=0; i<empleados.size(); i++){
    		l.add(empleados.get(i).toString());
    	}
    	return l;
    }
    
    /**
     * Devuelve una lista (ArrayList) con los nombres de los centros para poder cargar un ListView.
     * 
     * @return lista con los nombres de los centros
     */
    public ArrayList<String> listaCentros(){
    	ArrayList<String> l = new ArrayList<String>();
    	for(int i=0; i<centros.size(); i++){
    		l.add(centros.get(i).toString());
    	}
    	return l;
    }
    
    /**
     * Devuelve una lista (ArrayList) con las fechas/horas de inicio de cada turno para poder cargar un ListView.
     * 
     * @return lista con el inicio de cada turno
     */
    public ArrayList<String> listaTurnos(){
    	ArrayList<String> l = new ArrayList<String>();
    	for(int i=0; i<turnos.size(); i++){
    		l.add(turnos.get(i).toString());
    	}
    	return l;
    }
}
