/*
 * Copyright (C) 2013 Pablo Taboada
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package uoc.edu.ptaboada.tthome;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;

import org.apache.http.HttpResponse;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpUriRequest;
import org.apache.http.impl.client.DefaultHttpClient;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONTokener;

import android.os.AsyncTask;
import android.util.Log;

/**
 * Permite realizar peticiones HTTP en segundo plano, sin bloquear el Hilo de ejecución principal.
 * 
 * Al ser creada desdel Hilo principal, lanza un segundo hilo de ejecución en el que se realizarán las tareas
 * que pueden ser largas, como las peticiones HTTP al servidor.
 * Al finalizar, en el Hilo principal se especifica que hacer en caso de que la tarea haya finalizado 
 * con éxito o bien haya fracasado.
 * 
 * @author Pablo Taboada
 */
public class TareaHttp extends AsyncTask<HttpUriRequest, Void, JSONArray> {
	
	/**
	 * Tareas a realizar en segundo plano
	 * 
	 * @return Un array de elementos en sintaxis JSON
	 */
	@Override
	protected JSONArray doInBackground(HttpUriRequest...params) {
    	HttpUriRequest peticion = params[0];
    	HttpClient cliente = new DefaultHttpClient();

        try {
        	HttpResponse response =  cliente.execute(peticion);

        	BufferedReader reader = new BufferedReader(
        			new InputStreamReader(response.getEntity().getContent(), "UTF-8"));
        	String todo = "";
        	String linea = "";
			while ((linea = reader.readLine()) != null){
        		todo += linea;
        	}
			JSONArray json = (JSONArray) new JSONTokener(todo).nextValue();
			return json;
				
		}catch (JSONException e){
			Log.e(getClass().getSimpleName(),e.toString());
			// Problema de con el formato JSON de la respuesta del servidor:
			// puede darse en cualquier ocasión en que el servidor de una respuesta inesperada
			return null;
        } catch (ClientProtocolException e) {
        	Log.e(getClass().getSimpleName(),e.toString());
			e.printStackTrace();
			return null;
		} catch (IOException e) {
			Log.e(getClass().getSimpleName(),e.toString());
			e.printStackTrace();
			return null;
		}
    }

	/**
	 * Esta es la parte que se realizará en el Hilo principal
	 */
	protected void onPostExecute(JSONArray respuesta) {
        if(respuesta != null) {               
        	gestorTarea.tareaExito(respuesta);
        } else {
        	gestorTarea.tareaFracaso();
        }
    }
    

	/**
	 * Interfaz de implementación obligatoria al crear una nueva TaskHandler.
	 * Se deberá especificar, en el Hilo principal, que se debe de hacer cuando la tarea se haya
	 * completado con éxito o bien cuando haya fracasado
	 */
    public static interface GestorTareaHttp {
		void tareaExito(JSONArray respuesta);
		void tareaFracaso();
    }

    GestorTareaHttp gestorTarea;
    
    /**
     * Asigna un gestor de tareas a esta TareaHttp
     * 
     * @param gestor
     */
	public void setGestorTarea(GestorTareaHttp gestor) {
		this.gestorTarea = gestor;
	}
	
}