/*
 * Copyright (C) 2013 Pablo Taboada
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package uoc.edu.ptaboada.tthome;

import uoc.edu.ptaboada.tthome.R;

import android.app.ActionBar;
import android.app.Activity;
import android.os.Bundle;
import android.widget.TextView;

/**
 * Representa un Turno realizado por un Empleado en un Centro de trabajo en una fecha concreta
 * 
 * @author Pablo Taboada
 */
public class Turno extends Activity {
	public int id;
	public String centro;
	public String empleado;
	public String ini;
	public String fin;
	public int estado;
	
	// TODO: cambiar el tipo de entrada y salida del turno para mejorar el manejo de fechas.
	
	private String[] estados = {"Planificado",
								"En proceso",
								"Sin salida",
								"Eliminado",
								"Correcto",
								"No realizado",
								"No planificado"};

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.detalle);
		
		Bundle extras = getIntent().getExtras();
		String nome = extras.getString("nome");
				
		ActionBar ab = getActionBar();
		ab.show();
		ab.setIcon(R.drawable.img_turnos);
		ab.setTitle(nome);

		getDatosTurno(nome);

		TextView tv = (TextView) findViewById(R.id.detalle);
		tv.setText(
				 getString(R.string.centro)+":   "+centro+"\n"
				+getString(R.string.empleado)+": "+empleado+"\n"
				+getString(R.string.entrada)+":  "+ini+"\n"
				+getString(R.string.salida)+":   "+fin+"\n"
				+getString(R.string.estado)+":   "+estados[estado]+"\n");
	}
	
	/**
	 * constructor vacío para poder crear Activity vacía
	 */
	public Turno(){
		
	}
	
	/**
	 * Facilita la creación de un Turno proporcionando todos los datos del mismo.
	 * 
	 * @param id	identificador único del Turno
	 * @param ofi	centro de trabajo
	 * @param emp	empleado que realiza el Turno
	 * @param ini	fecha y hora de entrada
	 * @param fin	fecha y hora de salida
	 * @param ok	estado del Turno (realizado, no realizado, en proceso, ...)
	 */
	public Turno(int id, String ofi, String emp, String ini, String fin, int ok){
		this.id = id;
		this.centro = ofi;
		this.empleado = emp;
		this.ini = ini;
		this.fin = fin;
		this.estado = ok;
	}
	
	/**
	 * Devuelve únicamente la fecha y hora de inicio del Turno, para poblar la el ListView.
	 * 
	 * @return fecha y hora de inicio del Turno en formato ISO (yyyy-mm-dd hh:mm:ss)
	 */
	@Override
	public String toString() {
		return ini;
	}
	
	/**
	 * Asigna a este Turno los datos del Turno cuyo inicio es el pasado por parámetro
	 * 
	 * @param ini	fecha y hora de inicio del Turno en formato ISO (yyyy-mm-dd hh:mm:ss)
	 */
	private void getDatosTurno(String ini){
		TTApplication tt = (TTApplication)getApplication();
		for(int i=0; i<tt.turnos.size(); i++){
			if(tt.turnos.get(i).ini.equals(ini)){
				this.id = tt.turnos.get(i).id;
				this.centro = tt.turnos.get(i).centro;
				this.empleado = tt.turnos.get(i).empleado;
				this.ini = tt.turnos.get(i).ini;
				this.fin= tt.turnos.get(i).fin;
				this.estado = tt.turnos.get(i).estado;
				return;
			}
		}
		// TODO: realizar la búsqueda de datos del Turno en base a su ID en lugar de su inicio.
	}
}

