
-- CREACIÓN DE LA ESTRUCTURA DE LA BBDD:

CREATE DATABASE tthome;
USE tthome;

CREATE TABLE usuarios (
  id int(11) NOT NULL auto_increment,
  usuario varchar(50) default NULL,
  clave varchar(50) default NULL,
  nombre varchar(50) default NULL,
  email varchar(100) default NULL,
  idContrato int(11) default NULL,
  token varchar(32) default NULL,
  PRIMARY KEY (id),
  UNIQUE KEY (nombre),
  KEY (idContrato)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE provincias (
  id int(11) NOT NULL auto_increment,
  provincia varchar(50) default NULL,
  PRIMARY KEY (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE poblaciones (
  id int(11) NOT NULL auto_increment,
  poblacion varchar(50) default NULL,
  idProvincia int(11) default NULL,
  PRIMARY KEY  (id),
  FOREIGN KEY (idProvincia) REFERENCES provincias(id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE centros (
  id int(11) NOT NULL auto_increment,
  nombre varchar(50) default NULL,
  direccion varchar(60) default NULL,
  cp varchar(8) default NULL,
  idPoblacion int(11) default NULL,
  idContrato int(11) default NULL,
  PRIMARY KEY  (id),
  FOREIGN KEY (idPoblacion) REFERENCES poblaciones (id),
  FOREIGN KEY (idContrato) REFERENCES usuarios (idContrato)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE empleados (
  id int(11) NOT NULL auto_increment,
  nombre varchar(50) default NULL,
  codigo varchar(8) default NULL,
  telefono varchar(12) default NULL,
  idContrato int(11) default NULL,
  PRIMARY KEY  (id),
  UNIQUE KEY codigo (codigo),
  FOREIGN KEY (idContrato) REFERENCES usuarios(idContrato) 
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE estados (
  id tinyint(4) NOT NULL auto_increment,
  estado varchar(11) default NULL,
  PRIMARY KEY (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE turnos (
  id int(11) NOT NULL auto_increment,
  idEmpleado int(11) default NULL,
  idCentro int(11) default NULL,
  entrada datetime default NULL,
  salida datetime default NULL,
  idEstado tinyint(4) default NULL,
  PRIMARY KEY (id),
  FOREIGN KEY (idEmpleado) REFERENCES empleados (id),
  FOREIGN KEY (idCentro) REFERENCES centros (id),
  FOREIGN KEY (idEstado) REFERENCES estados (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


-- CREACIÓN DEL USUARIO DE CONEXIÓN DESDE PHP:

CREATE USER android IDENTIFIED BY 'UOC2013';
GRANT SELECT,INSERT,UPDATE,DELETE ON tthome.* TO android;


-- INTRODUCCION DE DATOS DE PRUEBA EN LA BBDD:

INSERT INTO usuarios VALUES (1,'uoc','5e2a1cc2ea428b23b6055534e546a638ea0de1b6','Prueba UOC','ptaboada@uoc.edu',1,'');

INSERT INTO provincias VALUES (1,'Araba'),(2,'Albacete'),(3,'Alicante'),(4,'Almeria'),(5,'Avila'),(6,'Badajoz'),(7,'Illes Balears'),(8,'Barcelona'),(9,'Burgos'),(10,'Cáceres'),(11,'Cádiz'),(12,'Castellón'),(13,'Ciudad Real'),(14,'Códoba'),(15,'A Coruña'),(16,'Cuenca'),(17,'Girona'),(18,'Granada'),(19,'Guadalajara'),(20,'Guipúzcoa'),(21,'Huelva'),(22,'Huesca'),(23,'Jaén'),(24,'León'),(25,'Lleida'),(26,'La Rioja'),(27,'Lugo'),(28,'Madrid'),(29,'Málaga'),(30,'Murcia'),(31,'Navarra'),(32,'Ourense'),(33,'Asturias'),(34,'Palencia'),(35,'Las Palmas'),(36,'Pontevedra'),(37,'Salamanca'),(38,'Santa Cruz de Tenerife'),(39,'Cantabria'),(40,'Segovia'),(41,'Sevilla'),(42,'Soria'),(43,'Tarragona'),(44,'Teruel'),(45,'Toledo'),(46,'Valencia'),(47,'Valladolid'),(48,'Bizcaia'),(49,'Zamora'),(50,'Zaragoza'),(51,'Ceuta'),(52,'Melilla');

INSERT INTO poblaciones VALUES (1,'Vigo',36),(2,'Barcelona',8);

INSERT INTO centros VALUES (1,'Casa','Avda. da Costa, sn','36201',1,1),(2,'Oficina','Travesía de Vigo, 426-2','36205',1,1),(3,'Chalet','Ronda Litoral, 5426','28080',2,1);

INSERT INTO empleados VALUES (1,'Limpiadora','95865746','900838383',1),(2,'Cocinera','76845132','900838383',1),(3,'Jardinero','98079875','900838383',1),(4,'Profesora','64798294','900838383',1);

INSERT INTO estados VALUES (0,'Planificada'),(1,'En proceso'),(2,'Sin salida'),(3,'Eliminado'),(4,'Correcto'),(5,'No atendido'),(6,'No planificado');

INSERT INTO turnos VALUES (1899,1,1,'2012-10-01 13:08:54','2012-10-01 13:00:00',2,1),(1900,2,1,'2012-10-01 15:56:44','2012-10-01 20:00:27',4,1),(1915,3,2,'2012-10-02 14:30:00','2012-10-02 18:30:00',5,1),(1916,1,1,'2012-10-02 09:06:19','2012-10-02 13:00:02',4,1),(1917,2,1,'2012-10-02 15:58:39','2012-10-02 20:01:33',4,1),(1929,1,1,'2012-10-03 10:16:10','2012-10-03 13:04:57',4,1),(1930,2,1,'2012-10-03 15:56:37','2012-10-03 20:00:00',2,1),(1932,3,2,'2012-10-03 15:41:26','2012-10-03 17:39:30',6,1),(1944,3,2,'2012-10-04 14:30:00','2012-10-04 18:30:00',5,1),(1945,1,1,'2012-10-04 09:04:57','2012-10-04 13:03:25',4,1),(1946,2,1,'2012-10-04 15:58:42','2012-10-04 20:12:08',4,1),(1961,3,2,'2012-10-05 14:30:00','2012-10-05 18:30:00',5,1),(1962,1,1,'2012-10-05 09:03:04','2012-10-05 13:07:27',4,1),(1963,2,1,'2012-10-05 19:59:49','2012-10-05 20:00:00',2,1),(1969,1,1,'2012-10-06 11:30:00','2012-10-06 13:00:00',5,1),(1987,1,1,'2012-10-08 09:06:46','2012-10-08 13:09:01',4,1),(1988,2,1,'2012-10-08 16:00:00','2012-10-08 20:00:00',5,1),(2004,3,2,'2012-10-09 15:26:11','2012-10-09 18:30:00',2,1),(2005,1,1,'2012-10-09 09:08:28','2012-10-09 12:59:07',4,1),(2006,2,1,'2012-10-09 16:00:00','2012-10-09 20:00:00',5,1),(2017,1,1,'2012-10-10 09:00:00','2012-10-10 13:00:00',5,1),(2018,2,1,'2012-10-10 16:00:00','2012-10-10 20:00:00',5,1),(2020,4,2,'2012-10-10 09:38:20','2012-10-10 20:46:52',6,1),(2032,3,2,'2012-10-11 14:30:00','2012-10-11 18:30:00',5,1),(2033,1,1,'2012-10-11 09:07:47','2012-10-11 12:43:27',4,1),(2034,2,1,'2012-10-11 16:00:00','2012-10-11 20:00:00',5,1),(2048,3,2,'2012-10-12 14:30:00','2012-10-12 18:30:00',5,1),(2049,1,1,'2012-10-12 09:00:00','2012-10-12 13:00:00',5,1),(2050,2,1,'2012-10-12 16:00:00','2012-10-12 20:00:00',5,1),(2055,1,1,'2012-10-13 11:21:18','2012-10-13 12:13:41',4,1),(2073,1,1,'2012-10-15 09:02:19','2012-10-15 12:56:10',4,1),(2074,2,1,'2012-10-15 16:00:00','2012-10-15 20:00:00',5,1),(2090,3,2,'2012-10-16 14:30:00','2012-10-16 18:30:00',5,1),(2091,1,1,'2012-10-16 09:00:00','2012-10-16 13:00:00',5,1),(2104,1,1,'2012-10-17 09:00:00','2012-10-17 13:00:00',5,1),(2118,4,2,'2012-10-18 09:26:07','2012-10-18 14:06:24',6,1),(2180,3,2,'2012-10-24 15:00:00','2012-10-24 18:00:00',5,1),(2194,3,2,'2012-10-25 15:47:23','2012-10-25 17:38:28',6,1),(2256,3,2,'2012-10-31 15:00:00','2012-10-31 18:00:00',5,1),(2331,3,2,'2012-11-07 15:00:00','2012-11-07 18:00:00',5,1),(2345,4,2,'2012-11-08 09:10:24','2012-11-08 19:55:51',6,1),(2397,4,2,'2012-11-13 09:01:21','2012-11-13 13:31:05',6,1),(2408,3,2,'2012-11-14 15:00:00','2012-11-14 18:00:00',5,1),(2483,3,2,'2012-11-21 15:00:00','2012-11-21 18:00:00',5,1),(2497,3,2,'2012-11-22 15:31:26','2012-11-22 17:53:17',6,1),(2559,3,2,'2012-11-28 15:41:49','2012-11-28 18:24:00',4,1),(2624,3,2,'2012-12-04 15:26:01','2012-12-04 17:48:10',6,1),(2635,3,2,'2012-12-05 15:00:00','2012-12-05 18:00:00',5,1),(2698,3,2,'2012-12-11 14:56:16','2012-12-11 15:27:04',6,1),(2709,3,2,'2012-12-12 15:00:00','2012-12-12 18:00:00',5,1),(2783,3,2,'2012-12-19 15:00:00','2012-12-19 18:00:00',5,1),(2797,3,2,'2012-12-20 15:33:08','2012-12-20 17:29:32',6,1),(2856,3,2,'2012-12-26 15:00:00','2012-12-26 18:00:00',5,1),(2868,3,2,'2012-12-27 15:32:08','2012-12-27 16:47:35',6,1),(2929,3,2,'2013-01-02 15:00:00','2013-01-02 18:00:00',5,1);


